-- Replace DefaultUnitAIs for custom units
CREATE TRIGGER VP_DefaultUnitAI_Replace
AFTER INSERT ON Units 
BEGIN
    UPDATE Units SET DefaultUnitAI = 'UNITAI_SKIRMISHER' WHERE Type = NEW.Type AND CombatClass = "UNITCOMBAT_ARCHER" AND IsMounted = 1;
    UPDATE Units SET DefaultUnitAI = 'UNITAI_SUBMARINE' WHERE Type = NEW.Type AND CombatClass = "UNITCOMBAT_SUBMARINE";
    UPDATE Units SET DefaultUnitAI = 'UNITAI_DEFENSE' WHERE Type = NEW.Type AND DefaultUnitAI = "UNITAI_COUNTER" AND AirInterceptRange = 0;
END;

-- Replace Unit_AITypes for custom units, using the newly set DefaultUnitAIs
CREATE TRIGGER VP_UnitAITypes_Replace
AFTER INSERT ON Unit_AITypes 
BEGIN
    UPDATE Unit_AITypes SET UnitAIType = 'UNITAI_SKIRMISHER' WHERE UnitAIType = 'UNITAI_COUNTER' AND UnitType IN (SELECT Type FROM Units WHERE DefaultUnitAI = "UNITAI_SKIRMISHER");
    UPDATE Unit_AITypes SET UnitAIType = 'UNITAI_SUBMARINE' WHERE UnitAIType = 'UNITAI_ASSAULT_SEA' AND UnitType IN (SELECT Type FROM Units WHERE DefaultUnitAI = "UNITAI_SUBMARINE");
    DELETE FROM Unit_AITypes WHERE UnitAIType = "UNITAI_COUNTER" AND UnitType NOT IN (SELECT Type FROM Units WHERE DefaultUnitAI = "UNITAI_COUNTER");
END;

-- Add default flavors to new leaders
CREATE TRIGGER VP_LeaderFlavors_Insert
AFTER INSERT ON Leaders
BEGIN
	INSERT INTO Leader_Flavors (LeaderType, FlavorType, Flavor) VALUES 
	(NEW.Type, 'FLAVOR_ARCHER', 5),
	(NEW.Type, 'FLAVOR_SIEGE', 5),
	(NEW.Type, 'FLAVOR_SKIRMISHER', 5),
	(NEW.Type, 'FLAVOR_NAVAL_MELEE', 5),
	(NEW.Type, 'FLAVOR_NAVAL_RANGED', 5),
	(NEW.Type, 'FLAVOR_SUBMARINE', 5),
	(NEW.Type, 'FLAVOR_BOMBER', 5),
	(NEW.Type, 'FLAVOR_FIGHTER', 5);
END;

-- Ugly safety check
INSERT INTO Leader_Flavors (LeaderType, FlavorType, Flavor)
	SELECT Type, 'FLAVOR_ARCHER', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_SIEGE', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_SKIRMISHER', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_NAVAL_MELEE', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_NAVAL_RANGED', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_SUBMARINE', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_BOMBER', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN") UNION ALL
	SELECT Type, 'FLAVOR_FIGHTER', 5 FROM Leaders WHERE Type NOT IN ("LEADER_AHMAD_ALMANSUR", "LEADER_ALEXANDER", "LEADER_ASHURBANIPAL", "LEADER_ASKIA", "LEADER_ATTILA", "LEADER_AUGUSTUS", "LEADER_BARBARIAN", "LEADER_BISMARCK", "LEADER_BOUDICCA", "LEADER_CASIMIR", "LEADER_CATHERINE", "LEADER_DARIUS", "LEADER_DIDO", "LEADER_ELIZABETH", "LEADER_ENRICO_DANDOLO", "LEADER_GAJAH_MADA", "LEADER_GANDHI", "LEADER_GENGHIS_KHAN", "LEADER_GUSTAVUS_ADOLPHUS", "LEADER_HARALD", "LEADER_HARUN_AL_RASHID", "LEADER_HIAWATHA","LEADER_ISABELLA", "LEADER_KAMEHAMEHA", "LEADER_MARIA", "LEADER_MARIA_I", "LEADER_MONTEZUMA", "LEADER_NAPOLEON", "LEADER_NEBUCHADNEZZAR", "LEADER_ODA_NOBUNAGA", "LEADER_PACAL", "LEADER_PACHACUTI", "LEADER_PEDRO", "LEADER_POCATELLO", "LEADER_RAMESSES", "LEADER_RAMKHAMHAENG", "LEADER_SEJONG", "LEADER_SELASSIE", "LEADER_SHAKA", "LEADER_SULEIMAN", "LEADER_THEODORA", "LEADER_WASHINGTON", "LEADER_WILLIAM", "LEADER_WU_ZETIAN");